@@ -25,7 +25,7 @@ use strict;
 use warnings;
 
 
-our $VERSION = "5.0.6";
+our $VERSION = "5.0.7";
 
 
 =head2 on_generate
@@ -44,7 +44,7 @@ then we skip regenerating them unless either:
 
 =item The C<--force> flag was used.
 
-=item The post was written within the past ten days.
+=item The post was written within the past ten days, and comments are enabled.
 
 =back
 
@@ -61,38 +61,92 @@ sub on_generate
     my $config = $args{ 'config' };
 
 
-    my $all = $dbh->prepare("SELECT id FROM blog") or
+    my $all = $dbh->prepare("SELECT id FROM blog ORDER BY date ASC") or
       die "Failed to find posts";
 
     my $now = time;
 
+    my @all = ();
+
     $all->execute() or die "Failed to execute:" . $dbh->errstr();
     my $id;
     $all->bind_columns( undef, \$id );
 
+    #
+    # Build up the list of all the post IDs
+    #
+    # We could build these on-demand, but instead maintain a list
+    # such that we can add next_link, next_title, etc, and allow
+    # paging through blog-entries.
+    #
     while ( $all->fetch() )
     {
+        push( @all, $id );
+    }
+
+
+    #
+    #  Now we have all the posts we iterate over them in-order.
+    #
+    for my $index ( 0 .. $#all )
+    {
+        my $id = $all[$index];
 
         #
-        #  Read the details of this single entry.
+        #  The previous blog entry and next blog entry, sequentially
+        #
+        my $prev_id = undef;
+        my $next_id = undef;
+
+        $prev_id = $all[$index - 1] if ( $index > 0 );
+        $next_id = $all[$index + 1] if ( $index < $#all );
+
+        #
+        #  Read the details of the main entry.
         #
         my $entry = Chronicle::getBlog( $dbh, $id );
 
         #
-        #  We skip posts that are already present - UNLESS they are posted
-        # within the past ten days.
+        #  Work out where it will be written to
         #
-        #  This means that we automatically include new comments when
-        # rebuilding a recent post.
+        my $out = $config->{ 'output' } . "/" . $entry->{ 'link' };
+
         #
-        #  Of course if you run "make clean" then you'll rebuild all
-        # pages, regardless of the age.
+        #  We skip posts that are already present:
         #
-        next
-          if ( ( -e $config->{ 'output' } . "/" . $entry->{ 'link' } ) &&
-               ( ( $now - $entry->{ 'posted' } ) >
-                 ( 60 * 60 * 24 * $config->{ 'comment-days' } ) ) &&
-               ( !$config->{ 'force' } ) );
+        #  * Unless they were posted recently and comments enabled.
+        #
+        # or
+        #
+        #  * The --force flag was used.
+        #
+
+        my $skip = 0;
+
+        #
+        #  So skip it if it exists.
+        #
+        $skip = 1 if ( -e $out );
+
+        #
+        # Unless --force overrides that.
+        #
+        $skip = 0 if ( $config->{ 'force' } );
+
+        #
+        # Finally if comments were enabled and this is recent then
+        # we'll also force it to be generated
+        #
+        $skip = 0
+          if ( ( $config->{ 'comments' } ) &&
+               ( ( $now - $entry->{ 'posted' } ) <
+                 ( 60 * 60 * 24 * $config->{ 'comment-days' } ) ) );
+
+
+        #
+        #  Loop again if we're skipping this post.
+        #
+        next if ($skip);
 
 
         $config->{ 'verbose' } &&
@@ -100,9 +154,28 @@ sub on_generate
 
 
         my $c = Chronicle::load_template("entry.tmpl");
+        return unless( $c );
         $c->param( top => $config->{ 'top' } );
         $c->param($entry);
 
+        #
+        #  If we have a prev/next entry then add their details too.
+        #
+        if ($prev_id)
+        {
+            my $prev = Chronicle::getBlog( $dbh, $prev_id );
+            $c->param( prev_id    => $prev_id,
+                       prev_title => $prev->{ 'title' },
+                       prev_link  => $prev->{ 'link' } );
+        }
+        if ($next_id)
+        {
+            my $next = Chronicle::getBlog( $dbh, $next_id );
+            $c->param( next_id    => $next_id,
+                       next_title => $next->{ 'title' },
+                       next_link  => $next->{ 'link' } );
+        }
+
         #
         #  Ensure we have a full output path - because a plugin might have given us a dated-path.
         #
